@@ -206,7 +206,12 @@ class MarkdownRenderer(Struct):
 
   def _render_header(self, fp, level, obj):
     if self.render_module_header_template and isinstance(obj, docspec.Module):
-      fp.write(self.render_module_header_template.format(module_name=obj.name))
+      fp.write(
+        self.render_module_header_template.format(
+          module_name=obj.name,
+          relative_module_name=obj.name.rsplit(".", 1)[1]
+        )
+      )
       return
 
     object_id = self._generate_object_id(obj)
@@ -267,7 +272,7 @@ class MarkdownRenderer(Struct):
     return code
 
   def _format_data_signature(self, data: docspec.Data) -> str:
-    expr = str(data.expr)
+    expr = str(data.value)
     if len(expr) > self.data_expression_maxlength:
       expr = expr[:self.data_expression_maxlength] + ' ...'
     return data.name + ' = ' + expr
